@@ -11,10 +11,10 @@ def _nest_items(nested_items, item, id_key, children_key):
 
 
 def nest(items, id_key, parent_id_key, children_key):
-    if any([id_key == parent_id_key,
-            id_key == children_key,
-            parent_id_key == children_key]):
-        raise ValueError('keys should be different.')
+    if any(
+        [id_key == parent_id_key, id_key == children_key, parent_id_key == children_key]
+    ):
+        raise ValueError("keys should be different.")
     nested_items = groupby(items, parent_id_key)
     root_items = nested_items.get(None, [])
     for item in root_items:
