@@ -18,7 +18,7 @@ def autodetect_format(s):
 def decode(s, format, **kwargs):
     serializer = get_serializer_by_format(format)
     if not serializer:
-        raise ValueError("Invalid format: {}.".format(format))
+        raise ValueError(f"Invalid format: {format}.")
     decode_opts = kwargs.copy()
     data = serializer.decode(s.strip(), **decode_opts)
     return data
@@ -27,7 +27,7 @@ def decode(s, format, **kwargs):
 def encode(d, format, **kwargs):
     serializer = get_serializer_by_format(format)
     if not serializer:
-        raise ValueError("Invalid format: {}.".format(format))
+        raise ValueError(f"Invalid format: {format}.")
     s = serializer.encode(d, **kwargs)
     return s
 
